![logo](https://cdn.discordapp.com/attachments/983572908553150484/984755765388648458/logo.png)

### **[Obito](https://naruto.fandom.com/wiki/Obito_Uchiha)** is a URL file downloader which can download multiple files concurrently over internet.

- **What's different?**
    - [x] Downloads multiple files through single command.
    - [x] Downloads files concurrently.
    - [ ] Support for large files.

## USAGE
![usage](https://user-images.githubusercontent.com/76993204/173182137-1499286b-bfed-40d9-889e-12ac9ff5a352.svg)

## Installation
#### ***PyPi***
```bash
pip install Obito
```
</br>

#### ***Manual Installation***
**Note:** You will need [Poetry](https://python-poetry.org/) for manual installation.
```bash
pip install poetry
```
</br>

1. Download or clone the repository.
```bash
git clone https://github.com/777advait/Obito
```

2. Install the project by running the following command in the root of the directory.
```bash
poetry install
```

## Examples
#### 1. Downloading Github API and Python concurrency docs
![example_1](https://user-images.githubusercontent.com/76993204/173182602-6ef5f13d-b1a7-4d52-9bf5-467fbf06d19e.gif)
</br>

#### 2. Downloading [Rust](https://rust-lang.org).
![example_2](https://user-images.githubusercontent.com/76993204/173183043-9d963973-be4f-48bd-b82e-ae1e4282d10d.gif)